@@ -95,7 +95,7 @@ def determine_heights(file):
     return heights
 
 
-def wrf_variable_processing(nc_paths, variables, heights, time_index_bool=None,  max_workers=4, **kwargs):
+def wrf_variable_processing(nc_paths, variables, heights, max_workers=4, **kwargs):
     """
 
     """
